@@ -146,7 +146,7 @@ class CassandraRepository(DBRepository[T, CassandraConfiguration]):
         limit: int = 500, offset: int = 0) -> List[T]:
 
         fields = '*' if not fields else ', '.join(fields)
-        clauses = list(filters.values) if filters else None
+        clauses = list(filter(None, filters.values)) if filters else None
         orders = list(filter(None, order_bys)) if order_bys and clauses else None  # Order by require filters
         sql = f"SELECT {fields} FROM {self.database}.{self.table_name()} " \
               f"{('WHERE ' + ' AND '.join(clauses)) if clauses else ''} " \
